@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '1.38';
+our $VERSION = '1.40';
 
 use Carp ();
 use DateTime;
@@ -26,7 +26,7 @@ use overload (
     'cmp'    => '_compare_overload',
 );
 
-use constant MAX_NANOSECONDS => 1_000_000_000;    # 1E9 = almost 32 bits
+sub MAX_NANOSECONDS () {1_000_000_000}    # 1E9 = almost 32 bits
 
 my @all_units = qw( months days minutes seconds nanoseconds );
 
@@ -344,7 +344,7 @@ DateTime::Duration - Duration objects for date math
 
 =head1 VERSION
 
-version 1.38
+version 1.40
 
 =head1 SYNOPSIS
 
@@ -622,8 +622,7 @@ http://datetime.perl.org/
 Support for this module is provided via the datetime@perl.org email
 list. See http://lists.perl.org/ for more details.
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime>
-(or L<bug-datetime@rt.cpan.org|mailto:bug-datetime@rt.cpan.org>).
+Bugs may be submitted through L<https://github.com/houseabsolute/DateTime.pm/issues>.
 
 There is a mailing list available for users of this distribution,
 L<mailto:datetime@perl.org>.
